@@ -428,3 +428,12 @@ def write_rule_tree(dict_type_tree, file_handle):
 def read_rule_tree(file_handle):
     with open(file_handle, "r") as read_file:
         return json.load(read_file)
+
+
+def get_not_target(s: pd.Series, target: str) -> pd.Series:
+    if s.dtype == np.object:
+        not_target = np.where(s != target, "not_target", "target")
+    else:
+        not_target = s * -1.0
+
+    return not_target
